======================
Contributing to Django
======================

As an open source project, Django welcomes contributions of many forms.

Examples of contributions include:

* Code patches
* Documentation improvements
* Bug reports and patch reviews

Extensive contribution guidelines are available in the repository at
``docs/internals/contributing/``, or online at:

https://docs.djangoproject.com/en/dev/internals/contributing/

**Warning: non-trivial pull requests (anything more than fixing a typo) without
Trac tickets will be closed!** `Please file a ticket`__ to suggest changes.

__ https://code.djangoproject.com/newticket

Django uses Trac to keep track of bugs, feature requests, and associated
patches because GitHub doesn't provide adequate tooling for its community.
Patches can be submitted as pull requests, but if you don't file a ticket,
it's unlikely that we'll notice your contribution.

Code of Conduct
===============

As a contributor, you can help us keep the Django community open and inclusive.
Please read and follow our `Code of Conduct <https://www.djangoproject.com/conduct/>`_.
